@@ -47,8 +47,8 @@ Palapeli::PuzzleCreatorDialog::PuzzleCreatorDialog()
 	, m_slicerConfigMasterWidget(new QStackedWidget)
 {
 	//setup dialog
-	setCaption(i18nc("@title:window", "Create new puzzle"));
-	showButton(KDialog::Help, false);
+	setWindowTitle(i18nc("@title:window", "Create new puzzle"));
+	buttonBox()->button(QDialogButtonBox::Help)->setVisible(false);
 	//setup image selector
 	m_imageSelector->setMode(KFile::File | KFile::LocalOnly | KFile::ExistingOnly);
 	//build sublayouts
@@ -72,12 +72,13 @@ Palapeli::PuzzleCreatorDialog::PuzzleCreatorDialog()
 	m_slicerConfigPage = addPage(m_slicerConfigMasterWidget, i18nc("@item:inlistbox (page name in an assistant dialog)", "Configure slicer"));
 	m_slicerConfigPage->setHeader(i18nc("@title:tab (page header in an assistant dialog)", "Tweak the parameters of the chosen slicing method"));
 	//wire up stuff
-	connect(this, SIGNAL(accepted()), this, SLOT(createPuzzle()));
-	connect(m_imageSelector, SIGNAL(urlSelected(KUrl)), this, SLOT(checkData()));
-	connect(m_nameEdit, SIGNAL(textChanged(QString)), this, SLOT(checkData()));
-	connect(m_authorEdit, SIGNAL(textChanged(QString)), this, SLOT(checkData()));
+	connect(this, &PuzzleCreatorDialog::accepted, this, &PuzzleCreatorDialog::createPuzzle);
+	connect(m_imageSelector, &KUrlRequester::urlSelected, this, &PuzzleCreatorDialog::checkData);
+	connect(m_nameEdit, &KLineEdit::textChanged, this, &PuzzleCreatorDialog::checkData);
+	connect(m_authorEdit, &KLineEdit::textChanged, this, &PuzzleCreatorDialog::checkData);
 	checkData(); //to invalidate first page
-	connect(m_slicerSelector, SIGNAL(currentSelectionChanged(Palapeli::SlicerSelection)), this, SLOT(updateSlicerSelection(Palapeli::SlicerSelection)));
+	setValid(m_slicerPage, false);
+	connect(m_slicerSelector, &Palapeli::SlicerSelector::currentSelectionChanged, this, &PuzzleCreatorDialog::updateSlicerSelection);
 }
 
 Palapeli::Puzzle* Palapeli::PuzzleCreatorDialog::result() const
@@ -146,4 +147,4 @@ void Palapeli::PuzzleCreatorDialog::createPuzzle()
 	m_result = new Palapeli::Puzzle(new Palapeli::CreationContextComponent(creationContext), QString(), QUuid::createUuid().toString());
 }
 
-#include "puzzlecreator.moc"
+
