@@ -28,6 +28,7 @@
 #include "view.h"
 #include "piece.h"
 #include "texturehelper.h"
+#include "interactormanager.h"
 #include "../file-io/puzzle.h"
 #include "../file-io/components.h"
 #include "../file-io/collection.h"
@@ -35,19 +36,19 @@
 
 #include "../config/configdialog.h"
 #include "settings.h"
-
-#include <QtGui/QStackedWidget>
+#include <QUrl>
+#include <QStackedWidget>
 #include <QPointer>
 #include <QPropertyAnimation>
 #include <QFutureWatcher>
 #include <QtCore/qmath.h>
+#include <QStandardPaths>
 #include <QInputDialog>
-#include <KDE/KAction>
-#include <KDE/KActionCollection>
-#include <KDE/KLocalizedString>
-#include <KDE/KMessageBox>
-#include <KDE/KFileDialog>
-#include <KStandardDirs>
+#include <QAction>
+#include <QFileDialog>
+#include <KActionCollection>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 // Use this because comma in type is not possible in foreach macro.
 typedef QPair<int, int> DoubleIntPair;
@@ -115,6 +116,7 @@ void Palapeli::GamePlay::deletePuzzleViews()
 		disconnect(scene, SIGNAL(saveMove(int)),
 			   this, SLOT(positionChanged(int)));
 		qDebug() << "scene->clearPieces();";
+		view->interactorManager()->resetActiveTriggers();
 		scene->clearPieces();
 		qDebug() << "if (scene != m_puzzleTableScene) {";
 		if (scene != m_puzzleTableScene) {
@@ -122,8 +124,8 @@ void Palapeli::GamePlay::deletePuzzleViews()
 			delete view;
 		}
 	}
-	m_currentHolder = 0;
-	m_previousHolder = 0;
+	m_currentHolder = nullptr;
+	m_previousHolder = nullptr;
 }
 
 void Palapeli::GamePlay::init()
@@ -167,6 +169,10 @@ void Palapeli::GamePlay::shutdown()
 void Palapeli::GamePlay::playPuzzle(Palapeli::Puzzle* puzzle)
 {
 	t.start();	// IDW test. START the clock.
+	// we need to load the preview every time, although when the puzzle
+	// is already loaded because the preview is destroyed in actionGoCollection()
+	QTimer::singleShot(0, this, SLOT(loadPreview()));
+
 	qDebug() << "START playPuzzle(): elapsed 0";
 	// Get some current action states from the collection.
 	m_canDeletePuzzle = m_mainWindow->actionCollection()->
@@ -206,8 +212,6 @@ void Palapeli::GamePlay::playPuzzle(Palapeli::Puzzle* puzzle)
 
 	// IDW TODO - There is no way to stop loading a puzzle and start loading
 	//            another. The only option is to Quit or abort Palapeli.
-
-	QTimer::singleShot(0, this, SLOT(loadPreview()));
 }
 
 void Palapeli::GamePlay::loadPreview()
@@ -220,7 +224,7 @@ void Palapeli::GamePlay::loadPreview()
 	// Palapeli must load the collection-list quickly at startup time).
 	const Palapeli::PuzzleComponent* as =
 		m_puzzle->get(Palapeli::PuzzleComponent::ArchiveStorage);
-	const Palapeli::PuzzleComponent* cmd = (as == 0) ? 0 :
+	const Palapeli::PuzzleComponent* cmd = (as == nullptr) ? nullptr :
 		as->cast(Palapeli::PuzzleComponent::Metadata);
 	if (cmd) {
 		// Load puzzle preview image from metadata.
@@ -229,11 +233,15 @@ void Palapeli::GamePlay::loadPreview()
 			metadata;
 		m_puzzlePreview->loadImageFrom(md);
 		m_mainWindow->setCaption(md.name);	// Set main title.
+		delete cmd;
 	}
 
 	m_puzzlePreview->setVisible(Settings::puzzlePreviewVisible());
 	connect (m_puzzlePreview, SIGNAL(closing()),
 		SLOT(actionTogglePreview()));	// Hide preview: do not delete.
+	// sync with mainWindow
+	m_mainWindow->actionCollection()->action("view_preview")->
+		setChecked(Settings::puzzlePreviewVisible());
 }
 
 void Palapeli::GamePlay::playPuzzleFile(const QString& path)
@@ -247,7 +255,7 @@ void Palapeli::GamePlay::actionGoCollection()
 {
 	m_centralWidget->setCurrentWidget(m_collectionView);
 	delete m_puzzlePreview;
-	m_puzzlePreview = 0;
+	m_puzzlePreview = nullptr;
 	m_mainWindow->setCaption(QString());
 	// IDW TODO - Disable piece-holder actions.
 	foreach (Palapeli::View* view, m_viewList) {
@@ -266,6 +274,8 @@ void Palapeli::GamePlay::actionTogglePreview()
 		m_puzzlePreview->toggleVisible();
 		m_mainWindow->actionCollection()->action("view_preview")->
 			setChecked(Settings::puzzlePreviewVisible());
+		// remember state
+		updateSavedGame();
 	}
 }
 
@@ -313,8 +323,11 @@ void Palapeli::GamePlay::actionDelete()
 
 void Palapeli::GamePlay::actionImport()
 {
-	const QString filter = i18nc("Filter for a file dialog", "*.puzzle|Palapeli puzzles (*.puzzle)");
-	const QStringList paths = KFileDialog::getOpenFileNames(KUrl("kfiledialog:///palapeli-import"), filter);
+	const QString filter = i18nc("Filter for a file dialog", "Palapeli puzzles (*.puzzle)");
+	const QStringList paths = QFileDialog::getOpenFileNames(m_mainWindow,
+															i18n("Import Palapeli puzzles"),
+															QString(),
+															filter);
 	Palapeli::Collection* coll = Palapeli::Collection::instance();
 	foreach (const QString& path, paths)
 		coll->importPuzzle(path);
@@ -335,9 +348,12 @@ void Palapeli::GamePlay::actionExport()
 		if (!cmp)
 			continue;
 		//ask user for target file name
-		const QString startLoc = QString::fromLatin1("kfiledialog:///palapeli-export/%1.puzzle").arg(cmp->metadata.name);
-		const QString filter = i18nc("Filter for a file dialog", "*.puzzle|Palapeli puzzles (*.puzzle)");
-		const QString location = KFileDialog::getSaveFileName(KUrl(startLoc), filter);
+		const QString startLoc = QString::fromLatin1("%1.puzzle").arg(cmp->metadata.name);
+		const QString filter = i18nc("Filter for a file dialog", "Palapeli puzzles (*.puzzle)");
+		const QString location = QFileDialog::getSaveFileName(m_mainWindow,
+															  i18n("Save Palapeli puzzles"),
+															  startLoc,
+															  filter);
 		if (location.isEmpty())
 			continue; //process aborted by user
 		//do export
@@ -411,8 +427,8 @@ void Palapeli::GamePlay::closeHolder(Palapeli::PieceHolder* h)
 		int count = m_viewList.count();
 		m_viewList.removeOne(h);
 		qDebug() << "m_viewList WAS" << count << "NOW" << m_viewList.count();
-		m_currentHolder = 0;
-		m_previousHolder = 0;
+		m_currentHolder = nullptr;
+		m_previousHolder = nullptr;
 		h->deleteLater();
 		positionChanged(0);	// Save change - a little later.
 	}
@@ -506,10 +522,12 @@ void Palapeli::GamePlay::restartPuzzle()
 		return;	// If no puzzle was successfully loaded and started.
 	}
 	// Discard the *.save file.
-	static const QString pathTemplate =
-			QString::fromLatin1("collection/%1.save");
-	QFile(KStandardDirs::locateLocal("appdata",
-			pathTemplate.arg(m_puzzle->identifier()))).remove();
+	const QString puzzleLoc(
+				QStandardPaths::locate(QStandardPaths::AppLocalDataLocation,
+									   saveGamePath() + saveGameFileName(m_puzzle->identifier())));
+	if (!puzzleLoc.isEmpty())
+		QFile(puzzleLoc).remove();
+
 	// Load the puzzle and re-shuffle the pieces.
 	loadPuzzle();
 }
@@ -517,7 +535,7 @@ void Palapeli::GamePlay::restartPuzzle()
 void Palapeli::GamePlay::teleport(Palapeli::Piece* pieceUnderMouse,
 				  const QPointF& scenePos, Palapeli::View* view)
 {
-	qDebug() << "GamePlay::teleport: pieceUnder" << (pieceUnderMouse != 0)
+	qDebug() << "GamePlay::teleport: pieceUnder" << (pieceUnderMouse != nullptr)
 		 << "scPos" << scenePos
 		 << "PuzzleTable?" << (view == m_puzzleTable->view())
 		 << "CurrentHolder?" << (view == m_currentHolder);
@@ -724,13 +742,17 @@ void Palapeli::GamePlay::loadPuzzle()
 	m_savegameTimer->stop(); // Just in case it is running ...
 	emit reportProgress(0, 0);
 	// Is there a saved game?
-	static const QString pathTemplate =
-				QString::fromLatin1("collection/%1.save");
-	KConfig savedConfig(KStandardDirs::locateLocal("appdata",
-				pathTemplate.arg(m_puzzle->identifier())));
-	if (savedConfig.hasGroup(AppearanceSaveGroup)) {
-		// Get settings for background, shadows, etc. in this puzzle.
-		restorePuzzleSettings(&savedConfig);
+	const QString puzzleLoc(
+				QStandardPaths::locate(QStandardPaths::AppLocalDataLocation,
+									   saveGamePath() + saveGameFileName(m_puzzle->identifier())));
+
+	if (!puzzleLoc.isEmpty())
+	{
+		KConfig savedConfig(puzzleLoc, KConfig::SimpleConfig);
+		if (savedConfig.hasGroup(AppearanceSaveGroup)) {
+			// Get settings for background, shadows, etc. in this puzzle.
+			restorePuzzleSettings(&savedConfig);
+		}
 	}
 	// Return to the event queue to start the loading-widget graphics ASAP.
 	QTimer::singleShot(0, this, SLOT(loadPuzzleFile()));
@@ -825,21 +847,24 @@ void Palapeli::GamePlay::loadPiecePositions()
 	m_puzzleTableScene->setPieceAreaSize(m_pieceAreaSize);
 
 	// Is there a saved game?
-	static const QString pathTemplate =
-				QString::fromLatin1("collection/%1.save");
-	KConfig savedConfig(KStandardDirs::locateLocal("appdata",
-				pathTemplate.arg(m_puzzle->identifier())));
+	const QString puzzleLoc(
+				QStandardPaths::locate(QStandardPaths::AppLocalDataLocation,
+									   saveGamePath() + saveGameFileName(m_puzzle->identifier())));
+	// empty -> file not found -> no saved game
 	bool oldFormat = false;
 	m_restoredGame = false;
 	int nHolders = 0;
-	if (savedConfig.hasGroup(HeaderSaveGroup)) {
-		KConfigGroup headerGroup(&savedConfig, HeaderSaveGroup);
-		nHolders = headerGroup.readEntry("N_Holders", 0);
-		m_restoredGame = true;
-	}
-	else if (savedConfig.hasGroup(FormerSaveGroup)) {
-		m_restoredGame = true;
-		oldFormat = true;
+	KConfig savedConfig(puzzleLoc, KConfig::SimpleConfig);	// here because needed inside 'if (m_restoredGame)'
+	if (!puzzleLoc.isEmpty()) {
+		if (savedConfig.hasGroup(HeaderSaveGroup)) {
+			KConfigGroup headerGroup(&savedConfig, HeaderSaveGroup);
+			nHolders = headerGroup.readEntry("N_Holders", 0);
+			m_restoredGame = true;
+		}
+		else if (savedConfig.hasGroup(FormerSaveGroup)) {
+			m_restoredGame = true;
+			oldFormat = true;
+		}
 	}
 	if (m_restoredGame)
 	{
@@ -857,7 +882,7 @@ void Palapeli::GamePlay::loadPiecePositions()
 			FormerSaveGroup : LocationSaveGroup);
 
 		// Re-create the saved piece-holders, if any.
-		m_currentHolder = 0;
+		m_currentHolder = nullptr;
 		for (int groupID = 1; groupID <= nHolders; groupID++) {
 			KConfigGroup holder (&savedConfig,
 					QString("Holder_%1").arg(groupID));
@@ -1106,7 +1131,7 @@ void Palapeli::GamePlay::finishLoading()
 			"puzzle table and its window can do, including joining "
 			"pieces to build up a part of the solution."),
 			i18nc("Caption for hints", "Solving Large Puzzles"),
-			QLatin1String("largepuzzle-introduction"));
+			QStringLiteral("largepuzzle-introduction"));
 	}
 	// Check if puzzle has been completed.
 	if (m_currentPieceCount == 1) {
@@ -1190,10 +1215,13 @@ void Palapeli::GamePlay::positionChanged(int reduction)
 
 void Palapeli::GamePlay::updateSavedGame()
 {
-	static const QString pathTemplate =
-				QString::fromLatin1("collection/%1.save");
-	KConfig savedConfig(KStandardDirs::locateLocal("appdata",
-				pathTemplate.arg(m_puzzle->identifier())));
+	QString path = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) +
+			QLatin1Char('/') + saveGamePath();
+	QDir d(path);
+	if (!d.exists())
+		d.mkpath(path);
+
+	KConfig savedConfig(path + saveGameFileName(m_puzzle->identifier()), KConfig::SimpleConfig);
 
 	savePuzzleSettings(&savedConfig);
 
@@ -1305,4 +1333,4 @@ void Palapeli::GamePlay::changeSelectedHolder(Palapeli::PieceHolder* h)
 	m_currentHolder = h;
 }
 
-#include "gameplay.moc"
+
