@@ -23,16 +23,15 @@
 #include "puzzletablewidget.h"
 #include "../file-io/collection-view.h"
 #include "settings.h"
+#include <QAction>
+#include <KActionCollection>
+#include <KLocalizedString>
+#include <KStandardAction>
+#include <KStandardShortcut>
+#include <KToggleAction>
+#include <KMessageBox>
 
-#include <KDE/KAction>
-#include <KDE/KActionCollection>
-#include <KDE/KCmdLineArgs>
-#include <KDE/KLocalizedString>
-#include <KDE/KStandardAction>
-#include <KDE/KToggleAction>
-#include <KDE/KMessageBox>
-
-Palapeli::MainWindow::MainWindow(KCmdLineArgs* args)
+Palapeli::MainWindow::MainWindow(const QString &path)
 	: m_game(new Palapeli::GamePlay(this))
 {
 	setupActions();
@@ -42,11 +41,8 @@ Palapeli::MainWindow::MainWindow(KCmdLineArgs* args)
 	setupGUI(QSize(500, 500), guiOptions);
 	m_game->init();
 	//start a puzzle if a puzzle URL has been given
-	if (args->count() != 0)
-	{
-		m_game->playPuzzleFile(args->arg(0));
-	}
-	args->clear();
+	if (!path.isEmpty())
+		m_game->playPuzzleFile(path);
 }
 
 bool Palapeli::MainWindow::queryClose()
@@ -61,27 +57,27 @@ void Palapeli::MainWindow::setupActions()
 	// Standard stuff.
 	KStandardAction::preferences(m_game, SLOT(configure()),
 						actionCollection());
-	KAction* statusBarAct = KStandardAction::showStatusbar
+	QAction * statusBarAct = KStandardAction::showStatusbar
 	(m_game->puzzleTable(), SLOT(showStatusBar(bool)), actionCollection());
 	statusBarAct->setChecked(Settings::showStatusBar());
 	statusBarAct->setText(i18n("Show statusbar of puzzle table"));
 
 	// Back to collection.
-	KAction* goCollAct = new KAction(KIcon("go-previous"), i18n("Back to &collection"), 0);
+	QAction * goCollAct = new QAction(QIcon::fromTheme("go-previous"), i18n("Back to &collection"), this);
 	goCollAct->setToolTip(i18n("Go back to the collection to choose another puzzle"));
 	goCollAct->setEnabled(false); //because the collection is initially shown
 	actionCollection()->addAction("view_collection", goCollAct);
 	connect(goCollAct, SIGNAL(triggered()), m_game, SLOT(actionGoCollection()));
 
 	// Create new puzzle (FIXME: action should have a custom icon).
-	KAction* createAct = new KAction(KIcon("tools-wizard"), i18n("Create &new puzzle..."), 0);
-	createAct->setShortcut(KStandardShortcut::openNew());
+	QAction * createAct = new QAction(QIcon::fromTheme("tools-wizard"), i18n("Create &new puzzle..."), this);
 	createAct->setToolTip(i18n("Create a new puzzle using an image file from your disk"));
+	actionCollection()->setDefaultShortcuts(createAct, KStandardShortcut::openNew());
 	actionCollection()->addAction("game_new", createAct);
 	connect(createAct, SIGNAL(triggered()), m_game, SLOT(actionCreate()));
 
 	// Delete a puzzle.
-	KAction* deleteAct = new KAction(KIcon("archive-remove"), i18n("&Delete puzzle"), 0);
+	QAction * deleteAct = new QAction(QIcon::fromTheme("archive-remove"), i18n("&Delete puzzle"), this);
 	deleteAct->setEnabled(false); //will be enabled when something is selected
 	deleteAct->setToolTip(i18n("Delete the selected puzzle from your collection"));
 	actionCollection()->addAction("game_delete", deleteAct);
@@ -89,13 +85,13 @@ void Palapeli::MainWindow::setupActions()
 	connect(deleteAct, SIGNAL(triggered()), m_game, SLOT(actionDelete()));
 
 	// Import from file...
-	KAction* importAct = new KAction(KIcon("document-import"), i18n("&Import from file..."), 0);
+	QAction * importAct = new QAction(QIcon::fromTheme("document-import"), i18n("&Import from file..."), this);
 	importAct->setToolTip(i18n("Import a new puzzle from a file into your collection"));
 	actionCollection()->addAction("game_import", importAct);
 	connect(importAct, SIGNAL(triggered()), m_game, SLOT(actionImport()));
 
 	// Export to file...
-	KAction* exportAct = new KAction(KIcon("document-export"), i18n("&Export to file..."), 0);
+	QAction * exportAct = new QAction(QIcon::fromTheme("document-export"), i18n("&Export to file..."), this);
 	exportAct->setEnabled(false); //will be enabled when something is selected
 	exportAct->setToolTip(i18n("Export the selected puzzle from your collection into a file"));
 	actionCollection()->addAction("game_export", exportAct);
@@ -103,7 +99,7 @@ void Palapeli::MainWindow::setupActions()
 	connect(exportAct, SIGNAL(triggered()), m_game, SLOT(actionExport()));
 
 	//Reshuffle and restart puzzle
-	KAction* restartPuzzleAct = new KAction(KIcon("view-refresh"), i18n("&Restart puzzle..."), 0);
+	QAction * restartPuzzleAct = new QAction(QIcon::fromTheme("view-refresh"), i18n("&Restart puzzle..."), this);
 	restartPuzzleAct->setToolTip(i18n("Delete the saved progress and reshuffle the pieces"));
 	restartPuzzleAct->setEnabled(false); //no puzzle in progress initially
 	actionCollection()->addAction("game_restart", restartPuzzleAct);
@@ -111,42 +107,42 @@ void Palapeli::MainWindow::setupActions()
 	// Quit.
 	KStandardAction::quit (this, SLOT (close()), actionCollection());
 	// Create piece-holder.
-	KAction* createHolderAct = new KAction(i18n("&Create piece holder..."), 0);
+	QAction * createHolderAct = new QAction(i18n("&Create piece holder..."), this);
 	createHolderAct->setToolTip(i18n("Create a temporary holder for sorting pieces"));
-	createHolderAct->setShortcut(QKeySequence(Qt::Key_C));
+	actionCollection()->setDefaultShortcut(createHolderAct, QKeySequence(Qt::Key_C));
 	actionCollection()->addAction("move_create_holder", createHolderAct);
 	connect(createHolderAct, SIGNAL(triggered()), m_game, SLOT(createHolder()));
 
 	// Delete piece-holder.
-	KAction* deleteHolderAct = new KAction(i18n("&Delete piece holder"), 0);
+	QAction * deleteHolderAct = new QAction(i18n("&Delete piece holder"), this);
 	deleteHolderAct->setToolTip(i18n("Delete a selected temporary holder when it is empty"));
-	deleteHolderAct->setShortcut(QKeySequence(Qt::Key_D));
+	actionCollection()->setDefaultShortcut(deleteHolderAct, QKeySequence(Qt::Key_D));
 	actionCollection()->addAction("move_delete_holder", deleteHolderAct);
 	connect(deleteHolderAct, SIGNAL(triggered()), m_game, SLOT(deleteHolder()));
 
 	// Select all pieces in a piece-holder.
-	KAction* selectAllAct = new KAction(i18n("&Select all in holder"), 0);
+	QAction * selectAllAct = new QAction(i18n("&Select all in holder"), this);
 	selectAllAct->setToolTip(i18n("Select all pieces in a selected piece holder"));
-	selectAllAct->setShortcut(QKeySequence(Qt::Key_A));
+	actionCollection()->setDefaultShortcut(selectAllAct, QKeySequence(Qt::Key_A));
 	actionCollection()->addAction("move_select_all", selectAllAct);
 	connect(selectAllAct, SIGNAL(triggered()), m_game, SLOT(selectAll()));
 
 	// Rearrange a selected piece-holder or selected pieces in any view.
-	KAction* rearrangeAct = new KAction(i18n("&Rearrange pieces"), 0);
+	QAction * rearrangeAct = new QAction(i18n("&Rearrange pieces"), this);
 	rearrangeAct->setToolTip(i18n("Rearrange all pieces in a selected piece holder or selected pieces in any window"));
-	rearrangeAct->setShortcut(QKeySequence(Qt::Key_R));
+	actionCollection()->setDefaultShortcut(rearrangeAct, QKeySequence(Qt::Key_R));
 	actionCollection()->addAction("move_rearrange", rearrangeAct);
 	connect(rearrangeAct, SIGNAL(triggered()), m_game, SLOT(rearrangePieces()));
 
 	// Toggle puzzle-preview.
 	bool  isVisible = Settings::puzzlePreviewVisible();
 	const QString text = i18nc("Preview is a noun here", "&Preview");
-	KToggleAction* togglePreviewAct = new KToggleAction(KIcon("view-preview"), text, 0);
+	KToggleAction* togglePreviewAct = new KToggleAction(QIcon::fromTheme("view-preview"), text, this);
 	togglePreviewAct->setIconText(i18nc("Preview is a noun here", "Preview"));
 	togglePreviewAct->setToolTip(i18n("Show or hide the image of the completed puzzle"));
 	actionCollection()->addAction("view_preview", togglePreviewAct);
 	togglePreviewAct->setEnabled(false);
-	togglePreviewAct->setChecked(false);
+	togglePreviewAct->setChecked(isVisible);
 	connect(togglePreviewAct, SIGNAL(triggered()), m_game, SLOT(actionTogglePreview()));
 
 	// View zoom in.
@@ -157,7 +153,7 @@ void Palapeli::MainWindow::setupActions()
 	KStandardAction::zoomOut(m_game, SLOT(actionZoomOut()),
 						actionCollection());
 	// Settings: enable messages that the user marked "Do not show again".
-	KAction* enableMessagesAct = new KAction(i18n("Enable all messages"),0);
+	QAction * enableMessagesAct = new QAction(i18n("Enable all messages"), this);
 	actionCollection()->addAction("enable_messages", enableMessagesAct);
 	connect(enableMessagesAct, SIGNAL(triggered()), SLOT(enableMessages()));
 }
@@ -170,8 +166,8 @@ void Palapeli::MainWindow::enableMessages()
 	if (result == KMessageBox::Yes) {
 		qDebug() << "ENABLE ALL MESSAGES";
 		KMessageBox::enableAllMessages();
-		KGlobal::config()->sync();	// Save the changes to disk.
+		KSharedConfig::openConfig()->sync();	// Save the changes to disk.
 	}
 }
 
-#include "mainwindow.moc"
+
